==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/kn_payment/moneyorder2.php <==
<?php
/*
  moneyorder2.php
  2004/11/1
ǽ

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
  
  moneyorderʶԿߡˤmoneyorder2͹ؿءˤˤ
*/

  class moneyorder2 {
    var $code, $title, $description, $enabled;

// class constructor
    function moneyorder2() {
      global $order;

      $this->code = 'moneyorder2';
      $this->title = MODULE_PAYMENT_MONEYORDER2_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_MONEYORDER2_TEXT_DESCRIPTION;
      $this->sort_order = MODULE_PAYMENT_MONEYORDER2_SORT_ORDER;
      $this->enabled = ((MODULE_PAYMENT_MONEYORDER2_STATUS == 'True') ? true : false);

      if ((int)MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID > 0) {
        $this->order_status = MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID;
      }

      if (is_object($order)) $this->update_status();
    
      $this->email_footer = MODULE_PAYMENT_MONEYORDER2_TEXT_EMAIL_FOOTER;
    }

// class methods
    function update_status() {
      global $order;

      if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_MONEYORDER2_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_MONEYORDER2_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->billing['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

    function javascript_validation() {
      return false;
    }

    function selection() {
      return array('id' => $this->code,
                   'module' => $this->title);
    }

    function pre_confirmation_check() {
      return false;
    }

    function confirmation() {
      return array('title' => MODULE_PAYMENT_MONEYORDER2_TEXT_DESCRIPTION);
    }

    function process_button() {
      return false;
    }

    function before_process() {
      return false;
    }

    function after_process() {
      return false;
    }

    function get_error() {
      return false;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_MONEYORDER2_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('͹ؿؤͭˤ', 'MODULE_PAYMENT_MONEYORDER2_STATUS', 'True', '͹ؿؤˤʧդޤ?', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now());");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values (':', 'MODULE_PAYMENT_MONEYORDER2_PAYTO', '', '̾ꤷƤ.', '6', '1', now());");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_PAYMENT_MONEYORDER2_SORT_ORDER', '0', 'ɽǤޤۤɾ̤ɽޤ.', '6', '0', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ŭϰ', 'MODULE_PAYMENT_MONEYORDER2_ZONE', '0', 'Ŭϰ򤹤ȡ򤷤ϰΤߤѲǽȤʤޤ.', '6', '2', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('ʸơ', 'MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID', '0', 'ꤷơŬѤޤ.', '6', '0', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array('MODULE_PAYMENT_MONEYORDER2_STATUS', 'MODULE_PAYMENT_MONEYORDER2_ZONE', 'MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID', 'MODULE_PAYMENT_MONEYORDER2_SORT_ORDER', 'MODULE_PAYMENT_MONEYORDER2_PAYTO');
    }
  }
?>

==> koshoten.net-2.2.0.tar.gz: koshoten-net/catalog/includes/modules/kn_payment/moneyorder2.php <==
<?php
/*
  moneyorder2.php
  2004/11/1
ǽ

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
  
  moneyorderʶԿߡˤmoneyorder2͹ؿءˤˤ
*/

  class moneyorder2 {
    var $code, $title, $description, $enabled;

// class constructor
    function moneyorder2() {
      global $order;

      $this->code = 'moneyorder2';
      $this->title = MODULE_PAYMENT_MONEYORDER2_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_MONEYORDER2_TEXT_DESCRIPTION;
      $this->sort_order = MODULE_PAYMENT_MONEYORDER2_SORT_ORDER;
      $this->enabled = ((MODULE_PAYMENT_MONEYORDER2_STATUS == 'True') ? true : false);

      if ((int)MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID > 0) {
        $this->order_status = MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID;
      }

      if (is_object($order)) $this->update_status();
    
      $this->email_footer = MODULE_PAYMENT_MONEYORDER2_TEXT_EMAIL_FOOTER;
    }

// class methods
    function update_status() {
      global $order;

      if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_MONEYORDER2_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_MONEYORDER2_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->billing['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

    function javascript_validation() {
      return false;
    }

    function selection() {
      return array('id' => $this->code,
                   'module' => $this->title,
                   'fields' => array(array('title' => nl2br(MODULE_PAYMENT_MONEYORDER2_TEXT_PROCESS), 'field' => '')));
    }

    function pre_confirmation_check() {
      return false;
    }

    function confirmation() {
      return array('title' => nl2br(MODULE_PAYMENT_MONEYORDER2_TEXT_PROCESS));
    }

    function process_button() {
      return false;
    }

    function before_process() {
      return false;
    }

    function after_process() {
      return false;
    }

    function get_error() {
      return false;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_MONEYORDER2_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ʧˡ', 'MODULE_PAYMENT_MONEYORDER2_TEXT_TITLE', '͹ؿ', 'ʧˡ̾', '6', '11' , now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('͹ؿؤͭˤ', 'MODULE_PAYMENT_MONEYORDER2_STATUS', 'True', '͹ؿؤˤʧդޤ?', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now());");
//      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values (':', 'MODULE_PAYMENT_MONEYORDER2_PAYTO', '', '̾ꤷƤ.', '6', '1', now());");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_PAYMENT_MONEYORDER2_SORT_ORDER', '0', 'ɽǤޤۤɾ̤ɽޤ.', '6', '0', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ŭϰ', 'MODULE_PAYMENT_MONEYORDER2_ZONE', '0', 'Ŭϰ򤹤ȡ򤷤ϰΤߤѲǽȤʤޤ.', '6', '2', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('ʸơ', 'MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID', '0', 'ꤷơŬѤޤ.', '6', '0', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ʧˡ', 'MODULE_PAYMENT_MONEYORDER2_TEXT_PROCESS', ':\n00000-0-000000 \nޤϤô', '쥸λʧˡ̤ɽǤ', '6', '12' , 'tep_cfg_textarea(', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('᡼ؤ', 'MODULE_PAYMENT_MONEYORDER2_TEXT_EMAIL_FOOTER', ':\n00000-0-000000 \n\nޤϤô', 'ʸǧ᡼ɵʸ̤Ǥ', '6', '13', 'tep_cfg_textarea(', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array('MODULE_PAYMENT_MONEYORDER2_TEXT_TITLE', 'MODULE_PAYMENT_MONEYORDER2_STATUS', 'MODULE_PAYMENT_MONEYORDER2_ZONE', 'MODULE_PAYMENT_MONEYORDER2_ORDER_STATUS_ID', 'MODULE_PAYMENT_MONEYORDER2_SORT_ORDER', 'MODULE_PAYMENT_MONEYORDER2_TEXT_PROCESS', 'MODULE_PAYMENT_MONEYORDER2_TEXT_EMAIL_FOOTER');
    }
  }
?>
